| run_app | R Documentation |
This function launches the Shiny web application located in the inst/app directory
of the installed package. The application provides an interactive interface for clustering analysis.
run_app()
No return value. This function is called for its side effect (launching the app).
if (interactive()) {
run_app()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.